==> firefox-8.0.source.tar.bz2: mozilla-release/toolkit/components/remote/nsXRemoteService.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:expandtab:shiftwidth=2:tabstop=8:
 */
/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is mozilla.org code.
 *
 * The Initial Developer of the Original Code is
 * Christopher Blizzard.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *   Christopher Blizzard <blizzard@mozilla.org>
 *   Benjamin Smedberg <benjamin@smedbergs.us>
 *   Miika Jarvinen <mjarvin@gmail.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#ifndef NSXREMOTESERVICE_H
#define NSXREMOTESERVICE_H

#include "nsString.h"

#include "nsIRemoteService.h"
#include "nsIObserver.h"
#include <X11/Xlib.h>
#include <X11/X.h>

class nsIDOMWindow;
class nsIWeakReference;

/**
  Base class for GTK/Qt remote service
*/
class nsXRemoteService : public nsIRemoteService,
                         public nsIObserver
{
public:
    NS_DECL_NSIOBSERVER


protected:
    nsXRemoteService();

    static PRBool HandleNewProperty(Window aWindowId,Display* aDisplay,
                                    Time aEventTime, Atom aChangedAtom,
                                    nsIWeakReference* aDomWindow);
    
    void XRemoteBaseStartup(const char *aAppName, const char *aProfileName);

    void HandleCommandsFor(Window aWindowId);
    static nsXRemoteService *sRemoteImplementation;
private:
    void EnsureAtoms();
    static const char* HandleCommand(char* aCommand, nsIDOMWindow* aWindow,
                                     PRUint32 aTimestamp);

    static const char* HandleCommandLine(char* aBuffer, nsIDOMWindow* aWindow,
                                         PRUint32 aTimestamp);

    virtual void SetDesktopStartupIDOrTimestamp(const nsACString& aDesktopStartupID,
                                                PRUint32 aTimestamp) = 0;

    nsCString mAppName;
    nsCString mProfileName;

    static Atom sMozVersionAtom;
    static Atom sMozLockAtom;
    static Atom sMozCommandAtom;
    static Atom sMozResponseAtom;
    static Atom sMozUserAtom;
    static Atom sMozProfileAtom;
    static Atom sMozProgramAtom;
    static Atom sMozCommandLineAtom;
};

#endif // NSXREMOTESERVICE_H

==> firefox-16.0.2.source.tar.bz2: mozilla-release/toolkit/components/remote/nsXRemoteService.h <==
/* -*- Mode: C++; tab-width: 8; indent-tabs-mode: nil; c-basic-offset: 2 -*- */
/* vim:expandtab:shiftwidth=2:tabstop=8:
 */
/* This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/. */

#ifndef NSXREMOTESERVICE_H
#define NSXREMOTESERVICE_H

#include "nsString.h"

#include "nsIRemoteService.h"
#include "nsIObserver.h"
#include <X11/Xlib.h>
#include <X11/X.h>

class nsIDOMWindow;
class nsIWeakReference;

/**
  Base class for GTK/Qt remote service
*/
class nsXRemoteService : public nsIRemoteService,
                         public nsIObserver
{
public:
    NS_DECL_NSIOBSERVER


protected:
    nsXRemoteService();

    static bool HandleNewProperty(Window aWindowId,Display* aDisplay,
                                    Time aEventTime, Atom aChangedAtom,
                                    nsIWeakReference* aDomWindow);
    
    void XRemoteBaseStartup(const char *aAppName, const char *aProfileName);

    void HandleCommandsFor(Window aWindowId);
    static nsXRemoteService *sRemoteImplementation;
private:
    void EnsureAtoms();
    static const char* HandleCommand(char* aCommand, nsIDOMWindow* aWindow,
                                     PRUint32 aTimestamp);

    static const char* HandleCommandLine(char* aBuffer, nsIDOMWindow* aWindow,
                                         PRUint32 aTimestamp);

    virtual void SetDesktopStartupIDOrTimestamp(const nsACString& aDesktopStartupID,
                                                PRUint32 aTimestamp) = 0;

    nsCString mAppName;
    nsCString mProfileName;

    static Atom sMozVersionAtom;
    static Atom sMozLockAtom;
    static Atom sMozCommandAtom;
    static Atom sMozResponseAtom;
    static Atom sMozUserAtom;
    static Atom sMozProfileAtom;
    static Atom sMozProgramAtom;
    static Atom sMozCommandLineAtom;
};

#endif // NSXREMOTESERVICE_H
